@@ -354,7 +354,7 @@ void BotQueueConsoleMessage( int chatstate, int type, char *message ) {
 	m->handle = cs->handle;
 	m->time = AAS_Time();
 	m->type = type;
-	strncpy( m->message, message, MAX_MESSAGE_SIZE );
+	Q_strncpyz( m->message, message, MAX_MESSAGE_SIZE );
 	m->next = NULL;
 	if ( cs->lastmessage ) {
 		cs->lastmessage->next = m;
@@ -384,7 +384,7 @@ int BotNextConsoleMessage( int chatstate, bot_consolemessage_t *cm ) {
 		return 0;
 	}
 	if ((firstmsg = cs->firstmessage)) {
-	cm->handle = firstmsg->handle;
+		cm->handle = firstmsg->handle;
 		cm->time = firstmsg->time;
 		cm->type = firstmsg->type;
 		Q_strncpyz(cm->message, firstmsg->message,
@@ -1134,8 +1134,7 @@ void BotDumpMatchTemplates( bot_matchtemplate_t *matches ) {
 	}
 	for ( mt = matches; mt; mt = mt->next )
 	{
-		// TTimo ?
-		// fprintf(fp, "%8d { ");
+		//fprintf(fp, "%8d { ");
 		for ( mp = mt->first; mp; mp = mp->next )
 		{
 			if ( mp->type == MT_STRING ) {
@@ -1469,7 +1468,7 @@ int BotFindMatch( char *str, bot_match_t *match, unsigned long int context ) {
 	int i;
 	bot_matchtemplate_t *ms;
 
-	strncpy( match->string, str, MAX_MESSAGE_SIZE );
+	Q_strncpyz( match->string, str, MAX_MESSAGE_SIZE );
 	//remove any trailing enters
 	while ( strlen( match->string ) &&
 			match->string[strlen( match->string ) - 1] == '\n' )
@@ -2016,7 +2015,7 @@ bot_chat_t *BotLoadInitialChat( char *chatfile, char *chatname ) {
 						StripDoubleQuotes( token.string );
 						if ( pass && ptr ) {
 							chattype = (bot_chattype_t *) ptr;
-							strncpy( chattype->name, token.string, MAX_CHATTYPE_NAME );
+							Q_strncpyz( chattype->name, token.string, MAX_CHATTYPE_NAME );
 							chattype->firstchatmessage = NULL;
 							//add the chat type to the chat
 							chattype->next = chat->types;
@@ -2755,7 +2754,7 @@ void BotSetChatName( int chatstate, char *name ) {
 		return;
 	}
 	memset( cs->name, 0, sizeof( cs->name ) );
-	strncpy( cs->name, name, sizeof( cs->name ) );
+	strncpy( cs->name, name, sizeof( cs->name ) - 1 );
 	cs->name[sizeof( cs->name ) - 1] = '\0';
 } //end of the function BotSetChatName
 //===========================================================================
