@@ -230,7 +230,8 @@ void CG_FilledBar( float x, float y, float w, float h, float *startColor, float
 		if ( endColor ) {
 			endColor[3] *= cg_hudAlpha.value;
 		}
-			backgroundcolor[3] *= cg_hudAlpha.value;
+
+		backgroundcolor[3] *= cg_hudAlpha.value;
 	}
 
 	if ( flags & BAR_LERP_COLOR ) {
@@ -362,7 +363,7 @@ void CG_DrawRect( float x, float y, float width, float height, float size, const
 	trap_R_SetColor( hudAlphaColor );
 
 	CG_DrawTopBottom( x, y, width, height, size );
-	CG_DrawSides( x, y, width, height, size );
+	CG_DrawSides( x, y + size, width, height - size * 2, size );
 
 	trap_R_SetColor( NULL );
 }
@@ -487,7 +488,7 @@ Coordinates are at 640 by 480 virtual resolution
 void CG_DrawStringExt( int x, int y, const char *string, const float *setColor,
 					   qboolean forceColor, qboolean shadow, int charWidth, int charHeight, int maxChars ) {
 	vec4_t color;
-	const char  *s;
+	const char *s;
 	int xx;
 	int cnt;
 
@@ -550,7 +551,7 @@ Coordinates are at 640 by 480 virtual resolution
 void CG_DrawStringExt2( int x, int y, const char *string, const float *setColor,
 						qboolean forceColor, qboolean shadow, int charWidth, int charHeight, int maxChars ) {
 	vec4_t color;
-	const char  *s;
+	const char *s;
 	int xx;
 	int cnt;
 
@@ -613,7 +614,7 @@ Coordinates are at 640 by 480 virtual resolution
 void CG_DrawStringExt3( int x, int y, const char *string, const float *setColor,
 						qboolean forceColor, qboolean shadow, int charWidth, int charHeight, int maxChars ) {
 	vec4_t color;
-	const char  *s;
+	const char *s;
 	int xx;
 	int cnt;
 
