@@ -126,7 +126,6 @@ static float shaderAnimSTRatio[MAX_SHADER_ANIMS] = {
 	1,
 };
 static int numShaderAnims;
-// done.
 
 #define     PARTICLE_GRAVITY    40
 #define     MAX_PARTICLES   1024 * 8
@@ -1039,10 +1038,6 @@ void CG_ParticleSnowFlurry( qhandle_t pshader, centity_t *cent ) {
 
 	VectorCopy( cent->currentState.origin, p->org );
 
-	p->org[0] = p->org[0];
-	p->org[1] = p->org[1];
-	p->org[2] = p->org[2];
-
 	p->vel[0] = p->vel[1] = 0;
 
 	p->accel[0] = p->accel[1] = p->accel[2] = 0;
@@ -1422,8 +1417,8 @@ void CG_ParticleDirtBulletDebris_Core( vec3_t org, vec3_t vel, int duration,
 
 	p->type = P_SMOKE;
 
-// JPW NERVE
 	p->pshader = trap_R_RegisterShader( shadername ); // JPW NERVE was "dirt_splash"
+// JPW NERVE
 	if ( cg_fxflags & 1 ) {
 		p->pshader = getTestShader();
 		p->rotate = 0;
@@ -1432,7 +1427,6 @@ void CG_ParticleDirtBulletDebris_Core( vec3_t org, vec3_t vel, int duration,
 	}
 // jpw
 
-
 	VectorCopy( org, p->org );
 	VectorCopy( vel, p->vel );
 
@@ -1445,8 +1439,6 @@ void CG_ParticleDirtBulletDebris_Core( vec3_t org, vec3_t vel, int duration,
 //	p->vel[2] += -20;
 }
 
-// DHM - Nerve :: end
-
 /*
 ======================
 CG_ParticleExplosion
@@ -1616,6 +1608,7 @@ void CG_ParticleBat( centity_t *cent ) {
 	if ( !free_particles ) {
 		return;
 	}
+
 	p = free_particles;
 	free_particles = p->next;
 	p->next = active_particles;
@@ -1980,8 +1973,8 @@ qboolean ValidBloodPool( vec3_t start ) {
 	vec3_t angles;
 	vec3_t right, up;
 	vec3_t this_pos, x_pos, center_pos, end_pos;
-	int x, y;
-	int fwidth, fheight;
+	int	x, y;
+	int	fwidth, fheight;
 	trace_t trace;
 	vec3_t normal;
 
