@@ -188,7 +188,8 @@ CG_CalcVrect
 Sets the coordinates of the rendered window
 =================
 */
-//static float letterbox_frac = 1.0f;	// used for transitioning to letterbox for cutscenes // TODO: add to cg. // TTimo: unused
+// TTimo: unused
+//static float letterbox_frac = 1.0f;	// used for transitioning to letterbox for cutscenes // TODO: add to cg.
 
 static void CG_CalcVrect( void ) {
 	int xsize, ysize;
@@ -1119,10 +1120,6 @@ static int CG_CalcViewValues( void ) {
 
 	memset( &cg.refdef, 0, sizeof( cg.refdef ) );
 
-	// strings for in game rendering
-	// Q_strncpyz( cg.refdef.text[0], "Park Ranger", sizeof(cg.refdef.text[0]) );
-	// Q_strncpyz( cg.refdef.text[1], "19", sizeof(cg.refdef.text[1]) );
-
 	// calculate size of 3D view
 	CG_CalcVrect();
 
@@ -1287,10 +1284,9 @@ CG_PowerupTimerSounds
 =====================
 */
 /*
-// TTimo: unused
 static void CG_PowerupTimerSounds( void ) {
-	int		i;
-	int		t;
+	int	i;
+	int	t;
 
 	// powerup timers going away
 	for ( i = 0 ; i < MAX_POWERUPS ; i++ ) {
@@ -1343,31 +1339,31 @@ void CG_DrawSkyBoxPortal( void ) {
 
 	if ( cg_skybox.integer ) {
 		token = COM_ParseExt( &cstr, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring\n" );
 		}
 		cg.refdef.vieworg[0] = atof( token );
 
 		token = COM_ParseExt( &cstr, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring\n" );
 		}
 		cg.refdef.vieworg[1] = atof( token );
 
 		token = COM_ParseExt( &cstr, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring\n" );
 		}
 		cg.refdef.vieworg[2] = atof( token );
 
 		token = COM_ParseExt( &cstr, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring\n" );
 		}
 
 		// setup fog the first time, ignore this part of the configstring after that
 		token = COM_ParseExt( &cstr, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring.  No fog state\n" );
 		} else {
 			vec4_t fogColor;
@@ -1376,32 +1372,32 @@ void CG_DrawSkyBoxPortal( void ) {
 			if ( atoi( token ) ) {   // this camera has fog
 				if ( 1 ) {
 					token = COM_ParseExt( &cstr, qfalse );
-					if ( !token || !token[0] ) {
+					if ( !token[0] ) {
 						CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring.  No fog[0]\n" );
 					}
 					fogColor[0] = atof( token );
 
 					token = COM_ParseExt( &cstr, qfalse );
-					if ( !token || !token[0] ) {
+					if ( !token[0] ) {
 						CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring.  No fog[1]\n" );
 					}
 					fogColor[1] = atof( token );
 
 					token = COM_ParseExt( &cstr, qfalse );
-					if ( !token || !token[0] ) {
+					if ( !token[0] ) {
 						CG_Error( "CG_DrawSkyBoxPortal: error parsing skybox configstring.  No fog[2]\n" );
 					}
 					fogColor[2] = atof( token );
 
 					token = COM_ParseExt( &cstr, qfalse );
-					if ( !token || !token[0] ) {
+					if ( !token[0] ) {
 						fogStart = 0;
 					} else {
 						fogStart = atoi( token );
 					}
 
 					token = COM_ParseExt( &cstr, qfalse );
-					if ( !token || !token[0] ) {
+					if ( !token[0] ) {
 						fogEnd = 0;
 					} else {
 						fogEnd = atoi( token );
@@ -1647,7 +1643,8 @@ void CG_DrawActiveFrame( int serverTime, stereoFrame_t stereoView, qboolean demo
 	DEBUGTIME
 
 	// decide on third person view
-	cg.renderingThirdPerson = cg_thirdPerson.integer || ( cg.snap->ps.stats[STAT_HEALTH] <= 0 );
+	cg.renderingThirdPerson = cg.snap->ps.persistant[PERS_TEAM] != TEAM_SPECTATOR
+							&& ( cg_thirdPerson.integer || ( cg.snap->ps.stats[STAT_HEALTH] <= 0 ) );
 
 	// build cg.refdef
 	inwater = CG_CalcViewValues();
@@ -1725,7 +1722,7 @@ void CG_DrawActiveFrame( int serverTime, stereoFrame_t stereoView, qboolean demo
 	DEBUGTIME
 
 	// warning sounds when powerup is wearing off
-	//CG_PowerupTimerSounds();
+//	CG_PowerupTimerSounds();
 
 	// make sure the lagometerSample and frame timing isn't done twice when in stereo
 	if ( stereoView != STEREO_RIGHT ) {
