@@ -57,19 +57,22 @@ LAN_LoadCachedServers
 void LAN_LoadCachedServers( void ) {
 	int size;
 	fileHandle_t fileIn;
+
 	cls.numglobalservers = cls.numfavoriteservers = 0;
 	cls.numGlobalServerAddresses = 0;
+
 	if ( FS_SV_FOpenFileRead( "servercache.dat", &fileIn ) ) {
 		FS_Read( &cls.numglobalservers, sizeof( int ), fileIn );
 		FS_Read( &cls.numfavoriteservers, sizeof( int ), fileIn );
 		FS_Read( &size, sizeof( int ), fileIn );
-		if (size == sizeof(cls.globalServers) + sizeof(cls.favoriteServers)) {
+		if ( size == sizeof( cls.globalServers ) + sizeof( cls.favoriteServers ) ) {
 			FS_Read( &cls.globalServers, sizeof( cls.globalServers ), fileIn );
 			FS_Read( &cls.favoriteServers, sizeof( cls.favoriteServers ), fileIn );
 		} else {
 			cls.numglobalservers = cls.numfavoriteservers = 0;
 			cls.numGlobalServerAddresses = 0;
 		}
+
 		FS_FCloseFile( fileIn );
 	}
 }
@@ -388,6 +391,7 @@ LAN_CompareServers
 static int LAN_CompareServers( int source, int sortKey, int sortDir, int s1, int s2 ) {
 	int res;
 	serverInfo_t *server1, *server2;
+	int clients1, clients2;
 
 	server1 = LAN_GetServerPtr( source, s1 );
 	server2 = LAN_GetServerPtr( source, s2 );
@@ -400,14 +404,22 @@ static int LAN_CompareServers( int source, int sortKey, int sortDir, int s1, int
 	case SORT_HOST:
 		res = Q_stricmp( server1->hostName, server2->hostName );
 		break;
-
 	case SORT_MAP:
 		res = Q_stricmp( server1->mapName, server2->mapName );
 		break;
 	case SORT_CLIENTS:
-		if ( server1->clients < server2->clients ) {
+		// sub sort by max clients
+		if ( server1->clients == server2->clients ) {
+			clients1 = server1->maxClients;
+			clients2 = server2->maxClients;
+		} else {
+			clients1 = server1->clients;
+			clients2 = server2->clients;
+		}
+
+		if ( clients1 < clients2 ) {
 			res = -1;
-		} else if ( server1->clients > server2->clients )     {
+		} else if ( clients1 > clients2 ) {
 			res = 1;
 		} else {
 			res = 0;
@@ -797,7 +809,7 @@ intptr_t CL_UISystemCalls( intptr_t *args ) {
 		return FS_FOpenFileByMode( VMA( 1 ), VMA( 2 ), args[3] );
 
 	case UI_FS_READ:
-		FS_Read2( VMA( 1 ), args[2], args[3] );
+		FS_Read( VMA( 1 ), args[2], args[3] );
 		return 0;
 
 	case UI_FS_WRITE:
@@ -1157,10 +1169,6 @@ void CL_InitUI( void ) {
 	// sanity check
 	v = VM_Call( uivm, UI_GETAPIVERSION );
 	if ( v != UI_API_VERSION ) {
-		// Free uivm now, so UI_SHUTDOWN doesn't get called later.
-//		VM_Free( uivm );
-//		uivm = NULL;
-
 		Com_Error( ERR_FATAL, "User Interface is version %d, expected %d", v, UI_API_VERSION );
 		cls.uiStarted = qfalse;
 	}
