@@ -67,14 +67,9 @@ BotNumActivePlayers
 int BotNumActivePlayers( void ) {
 	int i, num;
 	char buf[MAX_INFO_STRING];
-	static int maxclients;
-
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
 
 	num = 0;
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		trap_GetConfigstring( CS_PLAYERS + i, buf, sizeof( buf ) );
 		//if no config string or no name
 		if ( !strlen( buf ) || !strlen( Info_ValueForKey( buf, "n" ) ) ) {
@@ -98,15 +93,10 @@ BotIsFirstInRankings
 int BotIsFirstInRankings( bot_state_t *bs ) {
 	int i, score;
 	char buf[MAX_INFO_STRING];
-	static int maxclients;
 	playerState_t ps;
 
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
-
 	score = bs->cur_ps.persistant[PERS_SCORE];
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		trap_GetConfigstring( CS_PLAYERS + i, buf, sizeof( buf ) );
 		//if no config string or no name
 		if ( !strlen( buf ) || !strlen( Info_ValueForKey( buf, "n" ) ) ) {
@@ -117,8 +107,7 @@ int BotIsFirstInRankings( bot_state_t *bs ) {
 			continue;
 		}
 		//
-		BotAI_GetClientState( i, &ps );
-		if ( score < ps.persistant[PERS_SCORE] ) {
+		if ( BotAI_GetClientState( i, &ps ) && score < ps.persistant[PERS_SCORE] ) {
 			return qfalse;
 		}
 	}
@@ -133,15 +122,10 @@ BotIsLastInRankings
 int BotIsLastInRankings( bot_state_t *bs ) {
 	int i, score;
 	char buf[MAX_INFO_STRING];
-	static int maxclients;
 	playerState_t ps;
 
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
-
 	score = bs->cur_ps.persistant[PERS_SCORE];
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		trap_GetConfigstring( CS_PLAYERS + i, buf, sizeof( buf ) );
 		//if no config string or no name
 		if ( !strlen( buf ) || !strlen( Info_ValueForKey( buf, "n" ) ) ) {
@@ -152,8 +136,7 @@ int BotIsLastInRankings( bot_state_t *bs ) {
 			continue;
 		}
 		//
-		BotAI_GetClientState( i, &ps );
-		if ( score > ps.persistant[PERS_SCORE] ) {
+		if ( BotAI_GetClientState( i, &ps ) && score > ps.persistant[PERS_SCORE] ) {
 			return qfalse;
 		}
 	}
@@ -169,16 +152,11 @@ char *BotFirstClientInRankings( void ) {
 	int i, bestscore, bestclient;
 	char buf[MAX_INFO_STRING];
 	static char name[32];
-	static int maxclients;
 	playerState_t ps;
 
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
-
 	bestscore = -999999;
 	bestclient = 0;
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		trap_GetConfigstring( CS_PLAYERS + i, buf, sizeof( buf ) );
 		//if no config string or no name
 		if ( !strlen( buf ) || !strlen( Info_ValueForKey( buf, "n" ) ) ) {
@@ -189,8 +167,7 @@ char *BotFirstClientInRankings( void ) {
 			continue;
 		}
 		//
-		BotAI_GetClientState( i, &ps );
-		if ( ps.persistant[PERS_SCORE] > bestscore ) {
+		if ( BotAI_GetClientState( i, &ps ) && ps.persistant[PERS_SCORE] > bestscore ) {
 			bestscore = ps.persistant[PERS_SCORE];
 			bestclient = i;
 		}
@@ -208,16 +185,11 @@ char *BotLastClientInRankings( void ) {
 	int i, worstscore, bestclient;
 	char buf[MAX_INFO_STRING];
 	static char name[32];
-	static int maxclients;
 	playerState_t ps;
 
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
-
 	worstscore = 999999;
 	bestclient = 0;
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		trap_GetConfigstring( CS_PLAYERS + i, buf, sizeof( buf ) );
 		//if no config string or no name
 		if ( !strlen( buf ) || !strlen( Info_ValueForKey( buf, "n" ) ) ) {
@@ -228,8 +200,7 @@ char *BotLastClientInRankings( void ) {
 			continue;
 		}
 		//
-		BotAI_GetClientState( i, &ps );
-		if ( ps.persistant[PERS_SCORE] < worstscore ) {
+		if ( BotAI_GetClientState( i, &ps ) && ps.persistant[PERS_SCORE] < worstscore ) {
 			worstscore = ps.persistant[PERS_SCORE];
 			bestclient = i;
 		}
@@ -247,16 +218,11 @@ char *BotRandomOpponentName( bot_state_t *bs ) {
 	int i, count;
 	char buf[MAX_INFO_STRING];
 	int opponents[MAX_CLIENTS], numopponents;
-	static int maxclients;
 	static char name[32];
 
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
-
 	numopponents = 0;
 	opponents[0] = 0;
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		if ( i == bs->client ) {
 			continue;
 		}
