@@ -162,6 +162,8 @@ vmCvar_t url;
 
 vmCvar_t g_dbgRevive;
 
+vmCvar_t g_localTeamPref;
+
 cvarTable_t gameCvarTable[] = {
 	// don't override the cheat state set by the system
 	{ &g_cheats, "sv_cheats", "", 0, qfalse },
@@ -203,6 +205,7 @@ cvarTable_t gameCvarTable[] = {
 
 	{ &g_friendlyFire, "g_friendlyFire", "1", CVAR_SERVERINFO | CVAR_ARCHIVE, 0, qtrue  },
 
+	{ &g_teamAutoJoin, "g_teamAutoJoin", "0", CVAR_ARCHIVE  },
 	{ &g_teamForceBalance, "g_teamForceBalance", "0", CVAR_ARCHIVE  },                            // NERVE - SMF - merge from team arena
 
 	{ &g_warmup, "g_warmup", "20", CVAR_ARCHIVE, 0, qtrue  },
@@ -293,7 +296,9 @@ cvarTable_t gameCvarTable[] = {
 
 	{&g_antilag, "g_antilag", "0", CVAR_SERVERINFO | CVAR_ARCHIVE, 0, qfalse},
 
-	{&g_dbgRevive, "g_dbgRevive", "0", 0, 0, qfalse}
+	{&g_dbgRevive, "g_dbgRevive", "0", 0, 0, qfalse},
+
+	{ &g_localTeamPref, "g_localTeamPref", "", 0, 0, qfalse }
 };
 
 static int gameCvarTableSize = ARRAY_LEN( gameCvarTable );
@@ -879,7 +884,7 @@ void G_FindTeams( void ) {
 
 	c = 0;
 	c2 = 0;
-	for ( i = 1, e = g_entities + i ; i < level.num_entities ; i++,e++ ) {
+	for ( i = MAX_CLIENTS, e = g_entities + i ; i < level.num_entities ; i++,e++ ) {
 		if ( !e->inuse ) {
 			continue;
 		}
@@ -2757,9 +2762,6 @@ void G_RunFrame( int levelTime ) {
 		}
 	}
 
-	// see if it is time to do a tournement restart
-//	CheckTournament();
-
 	// NERVE - SMF
 	CheckWolfMP();
 
