@@ -500,9 +500,9 @@ void Com_StartupVariable( const char *match ) {
 		if(!match || !strcmp(s, match))
 		{
 			if(Cvar_Flags(s) == CVAR_NONEXISTENT)
-				Cvar_Get(s, Cmd_Argv(2), CVAR_USER_CREATED);
+				Cvar_Get(s, Cmd_ArgsFrom(2), CVAR_USER_CREATED);
 			else
-				Cvar_Set2(s, Cmd_Argv(2), qfalse);
+				Cvar_Set2(s, Cmd_ArgsFrom(2), qfalse);
 		}
 	}
 }
@@ -531,7 +531,7 @@ qboolean Com_AddStartupCommands( void ) {
 		}
 
 		// set commands already added with Com_StartupVariable
-		if ( !Q_stricmpn( com_consoleLines[i], "set", 3 ) ) {
+		if ( !Q_stricmpn( com_consoleLines[i], "set ", 4 ) ) {
 			continue;
 		}
 
@@ -918,7 +918,6 @@ Z_FreeTags
 ================
 */
 void Z_FreeTags( int tag ) {
-	int count;
 	memzone_t   *zone;
 
 	if ( tag == TAG_SMALL ) {
@@ -926,13 +925,11 @@ void Z_FreeTags( int tag ) {
 	} else {
 		zone = mainzone;
 	}
-	count = 0;
 	// use the rover as our pointer, because
 	// Z_Free automatically adjusts it
 	zone->rover = zone->blocklist.next;
 	do {
 		if ( zone->rover->tag == tag ) {
-			count++;
 			Z_Free( ( void * )( zone->rover + 1 ) );
 			continue;
 		}
@@ -1286,7 +1283,7 @@ Com_Meminfo_f
 void Com_Meminfo_f( void ) {
 	memblock_t  *block;
 	int zoneBytes, zoneBlocks;
-	int smallZoneBytes, smallZoneBlocks;
+	int smallZoneBytes;
 	int botlibBytes, rendererBytes;
 	int unused;
 
@@ -1324,11 +1321,9 @@ void Com_Meminfo_f( void ) {
 	}
 
 	smallZoneBytes = 0;
-	smallZoneBlocks = 0;
 	for ( block = smallzone->blocklist.next ; ; block = block->next ) {
 		if ( block->tag ) {
 			smallZoneBytes += block->size;
-			smallZoneBlocks++;
 		}
 
 		if ( block->next == &smallzone->blocklist ) {
@@ -2669,7 +2664,7 @@ static void Com_DetectSSE(void)
 #endif
 		Q_VMftol = qvmftolsse;
 
-		Com_Printf("Have SSE support\n");
+		Com_Printf("SSE instruction set enabled\n");
 #if !idx64
 	}
 	else
@@ -2678,7 +2673,7 @@ static void Com_DetectSSE(void)
 		Q_VMftol = qvmftolx87;
 		Q_SnapVector = qsnapvectorx87;
 
-		Com_Printf("No SSE support on this machine\n");
+		Com_Printf("SSE instruction set not available\n");
 	}
 #endif
 }
@@ -3060,6 +3055,13 @@ void Com_WriteConfig_f( void ) {
 
 	Q_strncpyz( filename, Cmd_Argv( 1 ), sizeof( filename ) );
 	COM_DefaultExtension( filename, sizeof( filename ), ".cfg" );
+
+	if (!COM_CompareExtension(filename, ".cfg"))
+	{
+		Com_Printf("Com_WriteConfig_f: Only the \".cfg\" extension is supported by this command!\n");
+		return;
+	}
+
 	Com_Printf( "Writing %s.\n", filename );
 	Com_WriteConfigToFile( filename );
 }
