@@ -114,9 +114,7 @@ void MSG_WriteBits( msg_t *msg, int value, int bits ) {
 
 	msg->uncompsize += bits;            // NERVE - SMF - net debugging
 
-	// this isn't an exact overflow check, but close enough
-	if ( msg->maxsize - msg->cursize < 4 ) {
-		msg->overflowed = qtrue;
+	if ( msg->overflowed ) {
 		return;
 	}
 
@@ -128,6 +126,11 @@ void MSG_WriteBits( msg_t *msg, int value, int bits ) {
 		bits = -bits;
 	}
 	if ( msg->oob ) {
+		if ( msg->cursize + ( bits >> 3 ) > msg->maxsize ) {
+			msg->overflowed = qtrue;
+			return;
+		}
+
 		if ( bits == 8 ) {
 			msg->data[msg->cursize] = value;
 			msg->cursize += 1;
@@ -150,6 +153,10 @@ void MSG_WriteBits( msg_t *msg, int value, int bits ) {
 		if ( bits & 7 ) {
 			int nbits;
 			nbits = bits & 7;
+			if ( msg->bit + nbits > msg->maxsize << 3 ) {
+				msg->overflowed = qtrue;
+				return;
+			}
 			for ( i = 0; i < nbits; i++ ) {
 				Huff_putBit( ( value & 1 ), msg->data, &msg->bit );
 				value = ( value >> 1 );
@@ -158,8 +165,13 @@ void MSG_WriteBits( msg_t *msg, int value, int bits ) {
 		}
 		if ( bits ) {
 			for ( i = 0; i < bits; i += 8 ) {
-				Huff_offsetTransmit( &msgHuff.compressor, ( value & 0xff ), msg->data, &msg->bit );
+				Huff_offsetTransmit( &msgHuff.compressor, ( value & 0xff ), msg->data, &msg->bit, msg->maxsize << 3 );
 				value = ( value >> 8 );
+
+				if ( msg->bit > msg->maxsize << 3 ) {
+					msg->overflowed = qtrue;
+					return;
+				}
 			}
 		}
 		msg->cursize = ( msg->bit >> 3 ) + 1;
@@ -173,6 +185,10 @@ int MSG_ReadBits( msg_t *msg, int bits ) {
 	int i, nbits;
 //	FILE*	fp;
 
+	if ( msg->readcount > msg->cursize ) {
+		return 0;
+	}
+
 	value = 0;
 
 	if ( bits < 0 ) {
@@ -183,6 +199,11 @@ int MSG_ReadBits( msg_t *msg, int bits ) {
 	}
 
 	if ( msg->oob ) {
+		if ( msg->readcount + ( bits >> 3 ) > msg->cursize ) {
+			msg->readcount = msg->cursize + 1;
+			return 0;
+		}
+
 		if ( bits == 8 ) {
 			value = msg->data[msg->readcount];
 			msg->readcount += 1;
@@ -205,6 +226,10 @@ int MSG_ReadBits( msg_t *msg, int bits ) {
 		nbits = 0;
 		if ( bits & 7 ) {
 			nbits = bits & 7;
+			if ( msg->bit + nbits > msg->cursize << 3 ) {
+				msg->readcount = msg->cursize + 1;
+				return 0;
+			}
 			for ( i = 0; i < nbits; i++ ) {
 				value |= ( Huff_getBit( msg->data, &msg->bit ) << i );
 			}
@@ -213,9 +238,14 @@ int MSG_ReadBits( msg_t *msg, int bits ) {
 		if ( bits ) {
 //			fp = fopen("c:\\netchan.bin", "a");
 			for ( i = 0; i < bits; i += 8 ) {
-				Huff_offsetReceive( msgHuff.decompressor.tree, &get, msg->data, &msg->bit );
+				Huff_offsetReceive( msgHuff.decompressor.tree, &get, msg->data, &msg->bit, msg->cursize << 3 );
 //				fwrite(&get, 1, 1, fp);
 				value |= ( get << ( i + nbits ) );
+
+				if ( msg->bit > msg->cursize << 3 ) {
+					msg->readcount = msg->cursize + 1;
+					return 0;
+				}
 			}
 //			fclose(fp);
 		}
@@ -280,8 +310,8 @@ void MSG_WriteLong( msg_t *sb, int c ) {
 }
 
 void MSG_WriteFloat( msg_t *sb, float f ) {
-
 	floatint_t dat;
+
 	dat.f = f;
 	MSG_WriteBits( sb, dat.i, 32 );
 }
@@ -409,7 +439,6 @@ int MSG_ReadLong( msg_t *msg ) {
 }
 
 float MSG_ReadFloat( msg_t *msg ) {
-
 	floatint_t dat;
 
 	dat.i = MSG_ReadBits( msg, 32 );
@@ -462,7 +491,6 @@ char *MSG_ReadBigString( msg_t *msg ) {
 		if ( c == '%' ) {
 			c = '.';
 		}
-
 		// don't allow higher ascii values
 		if ( c > 127 ) {
 			c = '.';
@@ -491,7 +519,6 @@ char *MSG_ReadStringLine( msg_t *msg ) {
 		if ( c == '%' ) {
 			c = '.';
 		}
-
 		// don't allow higher ascii values
 		if ( c > 127 ) {
 			c = '.';
