@@ -70,6 +70,7 @@ If you have questions concerning this license or the applicable additional terms
   #define HOMEPATH_NAME_WIN		"RTCW"
   #define STEAMPATH_NAME		"Return To Castle Wolfenstein"
   #define STEAMPATH_APPID		"9010"
+  #define GOGPATH_ID			"1441704976"
   #define HOMEPATH_NAME_MACOSX		HOMEPATH_NAME_WIN
   #define GAMENAME_FOR_MASTER		"wolfmp"
   #define CINEMATICS_LOGO		"gmlogo.RoQ"	// non-existent
@@ -87,7 +88,7 @@ If you have questions concerning this license or the applicable additional terms
 #define LEGACY_HEARTBEAT_FOR_MASTER	"Wolfenstein-1"
 
 #ifndef PRODUCT_VERSION
-  #define PRODUCT_VERSION "1.5a"
+  #define PRODUCT_VERSION "1.51-MP"
 #endif
 
 #ifndef OLD_PRODUCT_VERSION
