@@ -355,8 +355,8 @@ void R_AddAnimSurfaces( trRefEntity_t *ent ) {
 			if ( ent->e.renderfx & RF_BLINK ) {
 				const char *s = va( "%s_b", surface->name );   // append '_b' for 'blink'
 				for ( j = 0 ; j < skin->numSurfaces ; j++ ) {
-					if ( !strcmp( skin->surfaces[j]->name, s ) ) {
-						shader = skin->surfaces[j]->shader;
+					if ( !strcmp( skin->surfaces[j].name, s ) ) {
+						shader = skin->surfaces[j].shader;
 						break;
 					}
 				}
@@ -365,9 +365,8 @@ void R_AddAnimSurfaces( trRefEntity_t *ent ) {
 			if ( shader == tr.defaultShader ) {    // blink reference in skin was not found
 				for ( j = 0 ; j < skin->numSurfaces ; j++ ) {
 					// the names have both been lowercased
-
-					if ( !strcmp( skin->surfaces[j]->name, surface->name ) ) {
-						shader = skin->surfaces[j]->shader;
+					if ( !strcmp( skin->surfaces[j].name, surface->name ) ) {
+						shader = skin->surfaces[j].shader;
 						break;
 					}
 				}
@@ -1183,8 +1182,8 @@ void RB_SurfaceAnim( mdsSurface_t *surface ) {
 		
 		R_VaoPackNormal(tempNormal, newNormal);
 
-		tess.texCoords[baseVertex + j][0][0] = v->texCoords[0];
-		tess.texCoords[baseVertex + j][0][1] = v->texCoords[1];
+		tess.texCoords[baseVertex + j][0] = v->texCoords[0];
+		tess.texCoords[baseVertex + j][1] = v->texCoords[1];
 
 		v = (mdsVertex_t *)&v->weights[v->numWeights];
 	}
@@ -1605,9 +1604,9 @@ void R_MDRAddAnimSurfaces( trRefEntity_t *ent ) {
 			
 			for(j = 0; j < skin->numSurfaces; j++)
 			{
-				if (!strcmp(skin->surfaces[j]->name, surface->name))
+				if (!strcmp(skin->surfaces[j].name, surface->name))
 				{
-					shader = skin->surfaces[j]->shader;
+					shader = skin->surfaces[j].shader;
 					break;
 				}
 			}
@@ -1638,7 +1637,7 @@ void R_MDRAddAnimSurfaces( trRefEntity_t *ent ) {
 			R_AddDrawSurf( (void *)surface, tr.projectionShadowShader, 0, qfalse, qfalse, 0 );
 		}
 
-		if (!personalModel)
+		if ( !personalModel )
 			R_AddDrawSurf( (void *)surface, shader, fogNum, qfalse, qfalse, cubemapIndex );
 
 		surface = (mdrSurface_t *)( (byte *)surface + surface->ofsEnd );
@@ -1752,8 +1751,8 @@ void RB_MDRSurfaceAnim( mdrSurface_t *surface )
 
 		R_VaoPackNormal(tess.normal[baseVertex + j], tempNormal);
 
-		tess.texCoords[baseVertex + j][0][0] = v->texCoords[0];
-		tess.texCoords[baseVertex + j][0][1] = v->texCoords[1];
+		tess.texCoords[baseVertex + j][0] = v->texCoords[0];
+		tess.texCoords[baseVertex + j][1] = v->texCoords[1];
 
 		v = (mdrVertex_t *)&v->weights[v->numWeights];
 	}
