@@ -39,12 +39,19 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <psapi.h>
 #include <float.h>
 
+#ifndef KEY_WOW64_32KEY
+#define KEY_WOW64_32KEY 0x0200
+#endif
+
 // Used to determine where to store user-specific files
 static char homePath[ MAX_OSPATH ] = { 0 };
 
 #ifndef STANDALONE
 // Used to store the Steam RTCW installation path
 static char steamPath[ MAX_OSPATH ] = { 0 };
+
+// Used to store the GOG RTCW installation path
+static char gogPath[ MAX_OSPATH ] = { 0 };
 #endif
 
 #ifndef DEDICATED
@@ -152,6 +159,8 @@ char *Sys_SteamPath( void )
 		pathLen = MAX_OSPATH;
 		if (RegQueryValueEx(steamRegKey, "InstallLocation", NULL, NULL, (LPBYTE)steamPath, &pathLen))
 			steamPath[0] = '\0';
+
+		RegCloseKey(steamRegKey);
 	}
 #endif
 
@@ -165,6 +174,8 @@ char *Sys_SteamPath( void )
 
 		if (steamPath[0])
 			finishPath = qtrue;
+
+		RegCloseKey(steamRegKey);
 	}
 #endif
 
@@ -182,6 +193,38 @@ char *Sys_SteamPath( void )
 
 	return steamPath;
 }
+
+/*
+================
+Sys_GogPath
+================
+*/
+char *Sys_GogPath( void )
+{
+#ifdef GOGPATH_ID
+	HKEY gogRegKey;
+	DWORD pathLen = MAX_OSPATH;
+
+	if (!gogPath[0] && !RegOpenKeyEx(HKEY_LOCAL_MACHINE, "SOFTWARE\\GOG.com\\Games\\" GOGPATH_ID, 0, KEY_QUERY_VALUE | KEY_WOW64_32KEY, &gogRegKey))
+	{
+		pathLen = MAX_OSPATH;
+		if (RegQueryValueEx(gogRegKey, "PATH", NULL, NULL, (LPBYTE)gogPath, &pathLen))
+			gogPath[0] = '\0';
+
+		RegCloseKey(gogRegKey);
+	}
+
+	if (gogPath[0])
+	{
+		if (pathLen == MAX_OSPATH)
+			pathLen--;
+
+		gogPath[pathLen] = '\0';
+	}
+#endif
+
+	return gogPath;
+}
 #endif
 
 /*
@@ -864,10 +907,31 @@ qboolean Sys_PIDIsRunning( int pid )
 	return qfalse;
 }
 
+/*
+=================
+Sys_DllExtension
+
+Check if filename should be allowed to be loaded as a DLL.
+=================
+*/
+qboolean Sys_DllExtension( const char *name ) {
+	return COM_CompareExtension( name, DLL_EXT );
+}
+
+/*
+==============
+Sys_GetDLLName
+==============
+*/
 char* Sys_GetDLLName( const char *name ) {
 	return va("%s_mp_" ARCH_STRING DLL_EXT, name);
 }
 
+/*
+==============
+Sys_GetHighQualityCPU
+==============
+*/
 int Sys_GetHighQualityCPU() {
 	return 1;
 }
