@@ -276,9 +276,6 @@ void CG_AddParticleToScene( cparticle_t *p, vec3_t org, float alpha ) {
 				return;
 			}
 		}
-
-
-
 		// done.
 
 		if ( p->type == P_BUBBLE || p->type == P_BUBBLE_TURBULENT ) {
@@ -460,7 +457,6 @@ void CG_AddParticleToScene( cparticle_t *p, vec3_t org, float alpha ) {
 			}
 		}
 
-
 		if ( p->color == MUSTARD ) {
 			VectorSet( color, 0.42, 0.33, 0.19 );
 		} else if ( p->color == BLOODRED ) {
@@ -1099,10 +1095,6 @@ void CG_ParticleSnowFlurry( qhandle_t pshader, centity_t *cent ) {
 
 	VectorCopy( cent->currentState.origin, p->org );
 
-	p->org[0] = p->org[0];
-	p->org[1] = p->org[1];
-	p->org[2] = p->org[2];
-
 	p->vel[0] = p->vel[1] = 0;
 
 	p->accel[0] = p->accel[1] = p->accel[2] = 0;
@@ -1502,10 +1494,10 @@ void CG_ParticleDirtBulletDebris_Core( vec3_t org, vec3_t vel, int duration,
 
 	p->rotate = 0;
 
-	p->pshader = trap_R_RegisterShader( shadername ); // JPW NERVE was "dirt_splash"
-
 	p->type = P_SMOKE;
 
+	p->pshader = trap_R_RegisterShader( shadername ); // JPW NERVE was "dirt_splash"
+
 	VectorCopy( org, p->org );
 	VectorCopy( vel, p->vel );
 
@@ -2077,8 +2069,8 @@ qboolean ValidBloodPool( vec3_t start ) {
 	vec3_t angles;
 	vec3_t right, up;
 	vec3_t this_pos, x_pos, center_pos, end_pos;
-	int		x, y;
-	int		fwidth, fheight;
+	int	x, y;
+	int	fwidth, fheight;
 	trace_t trace;
 	vec3_t normal;
 
@@ -2104,11 +2096,13 @@ qboolean ValidBloodPool( vec3_t start ) {
 			CG_Trace( &trace, this_pos, NULL, NULL, end_pos, -1, CONTENTS_SOLID );
 
 
-			if (trace.entityNum < ENTITYNUM_WORLD) // may only land on world
+			if ( trace.entityNum <  ENTITYNUM_WORLD  ) { // may only land on world
 				return qfalse;
+			}
 
-			if ( !( !trace.startsolid && trace.fraction < 1 ) )
+			if ( !( !trace.startsolid && trace.fraction < 1 ) ) {
 				return qfalse;
+			}
 
 		}
 	}
