@@ -543,7 +543,10 @@ int BotAI( int client, float thinktime ) {
 	}
 
 	//retrieve the current client state
-	BotAI_GetClientState( client, &bs->cur_ps );
+	if ( !BotAI_GetClientState( client, &bs->cur_ps ) ) {
+		BotAI_Print( PRT_FATAL, "BotAI: failed to get player state for player %d\n", client );
+		return qfalse;
+	}
 
 	//retrieve any waiting console messages
 	while ( trap_BotGetServerCommand( client, buf, sizeof( buf ) ) ) {
@@ -1052,10 +1055,7 @@ int BotInitLibrary( void ) {
 	char buf[144];
 
 	//set the maxclients and maxentities library variables before calling BotSetupLibrary
-	trap_Cvar_VariableStringBuffer( "sv_maxclients", buf, sizeof( buf ) );
-	if ( !strlen( buf ) ) {
-		strcpy( buf, "8" );
-	}
+	Com_sprintf( buf, sizeof( buf ), "%d", level.maxclients );
 	trap_BotLibVarSet( "maxclients", buf );
 	Com_sprintf( buf, sizeof( buf ), "%d", MAX_GENTITIES );
 	trap_BotLibVarSet( "maxentities", buf );
