@@ -77,14 +77,9 @@ BotNumTeamMates
 int BotNumTeamMates( bot_state_t *bs ) {
 	int i, numplayers;
 	char buf[MAX_INFO_STRING];
-	static int maxclients;
-
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
 
 	numplayers = 0;
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		trap_GetConfigstring( CS_PLAYERS + i, buf, sizeof( buf ) );
 		//if no config string or no name
 		if ( !strlen( buf ) || !strlen( Info_ValueForKey( buf, "n" ) ) ) {
@@ -111,8 +106,12 @@ int BotClientTravelTimeToGoal( int client, bot_goal_t *goal ) {
 	playerState_t ps;
 	int areanum;
 
-	BotAI_GetClientState( client, &ps );
-	areanum = BotPointAreaNum( ps.origin );
+	if ( BotAI_GetClientState( client, &ps ) ) {
+		areanum = BotPointAreaNum( ps.origin );
+	} else {
+		areanum = 0;
+	}
+
 	if ( !areanum ) {
 		return 1;
 	}
@@ -128,7 +127,6 @@ int BotSortTeamMatesByBaseTravelTime( bot_state_t *bs, int *teammates, int maxte
 
 	int i, j, k, numteammates, traveltime;
 	char buf[MAX_INFO_STRING];
-	static int maxclients;
 	int traveltimes[MAX_CLIENTS];
 	bot_goal_t *goal;
 
@@ -136,12 +134,8 @@ int BotSortTeamMatesByBaseTravelTime( bot_state_t *bs, int *teammates, int maxte
 		goal = &ctf_redflag;
 	} else { goal = &ctf_blueflag;}
 
-	if ( !maxclients ) {
-		maxclients = trap_Cvar_VariableIntegerValue( "sv_maxclients" );
-	}
-
 	numteammates = 0;
-	for ( i = 0; i < maxclients && i < MAX_CLIENTS; i++ ) {
+	for ( i = 0; i < level.maxclients; i++ ) {
 		trap_GetConfigstring( CS_PLAYERS + i, buf, sizeof( buf ) );
 		//if no config string or no name
 		if ( !strlen( buf ) || !strlen( Info_ValueForKey( buf, "n" ) ) ) {
