@@ -541,12 +541,12 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 	// read optional parameters
 	while ( 1 ) {
 		token = COM_Parse( &text_p );
-		if ( !token ) {
+		if ( !token[0] ) {
 			break;
 		}
 		if ( !Q_stricmp( token, "footsteps" ) ) {
 			token = COM_Parse( &text_p );
-			if ( !token ) {
+			if ( !token[0] ) {
 				break;
 			}
 			if ( !Q_stricmp( token, "default" ) || !Q_stricmp( token, "normal" ) ) {
@@ -566,7 +566,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 		} else if ( !Q_stricmp( token, "headoffset" ) ) {
 			for ( i = 0 ; i < 3 ; i++ ) {
 				token = COM_Parse( &text_p );
-				if ( !token ) {
+				if ( !token[0] ) {
 					break;
 				}
 				animModelInfo->headOffset[i] = atof( token );
@@ -574,7 +574,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 			continue;
 		} else if ( !Q_stricmp( token, "sex" ) ) {
 			token = COM_Parse( &text_p );
-			if ( !token ) {
+			if ( !token[0] ) {
 				break;
 			}
 			if ( token[0] == 'f' || token[0] == 'F' ) {
@@ -587,7 +587,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 			continue;
 		} else if ( !Q_stricmp( token, "version" ) ) {
 			token = COM_Parse( &text_p );
-			if ( !token ) {
+			if ( !token[0] ) {
 				break;
 			}
 			animModelInfo->version = atoi( token );
@@ -616,7 +616,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 	for ( i = 0 ; ( animModelInfo->version > 1 ) || ( i < MAX_ANIMATIONS ) ; i++ ) {
 
 		token = COM_Parse( &text_p );
-		if ( !token ) {
+		if ( !token[0] ) {
 			break;
 		}
 
@@ -631,7 +631,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 			Q_strlwr( animations[i].name );
 			//
 			token = COM_ParseExt( &text_p, qfalse );
-			if ( !token || !token[0] ) {
+			if ( !token[0] ) {
 				BG_AnimParseError( "end of file without ENDANIMS" );
 				break;
 			}
@@ -657,21 +657,21 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 		}
 
 		token = COM_ParseExt( &text_p, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			BG_AnimParseError( "end of file without ENDANIMS" );
 			break;
 		}
 		animations[i].numFrames = atoi( token );
 
 		token = COM_ParseExt( &text_p, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			BG_AnimParseError( "end of file without ENDANIMS: line %i", COM_GetCurrentParseLine() + 1 );
 			break;
 		}
 		animations[i].loopFrames = atoi( token );
 
 		token = COM_ParseExt( &text_p, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			BG_AnimParseError( "end of file without ENDANIMS: line %i", COM_GetCurrentParseLine() + 1 );
 			break;
 		}
@@ -684,7 +684,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 
 		// movespeed
 		token = COM_ParseExt( &text_p, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			BG_AnimParseError( "end of file without ENDANIMS" );
 			break;
 		}
@@ -693,7 +693,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 		// animation blending
 		oldtext_p = text_p;
 		token = COM_ParseExt( &text_p, qfalse );    // must be on same line
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			text_p = oldtext_p;
 			animations[i].animBlend = 0;
 		} else {
@@ -703,7 +703,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 		// priority
 		oldtext_p = text_p;
 		token = COM_ParseExt( &text_p, qfalse );    // must be on same line
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			text_p = oldtext_p;
 			// death anims have highest priority
 			if ( !Q_strncmp( animations[i].name, "death", 5 ) ) {
@@ -749,14 +749,14 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 			for ( i = 0 ; i < MAX_HEAD_ANIMS ; i++ ) {
 
 				token = COM_Parse( &text_p );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					break;
 				}
 
 				if ( animModelInfo->version > 1 ) {   // includes animation names at start of each line
 					// just throw this information away, not required for head
 					token = COM_ParseExt( &text_p, qfalse );
-					if ( !token || !token[0] ) {
+					if ( !token[0] ) {
 						break;
 					}
 				}
@@ -770,7 +770,7 @@ qboolean BG_AnimParseAnimConfig( animModelInfo_t *animModelInfo, const char *fil
 				headAnims[i].firstFrame -= animations[MAX_ANIMATIONS - 1].firstFrame + animations[MAX_ANIMATIONS - 1].numFrames + skip;
 
 				token = COM_ParseExt( &text_p, qfalse );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					break;
 				}
 				headAnims[i].numFrames = atoi( token );
@@ -815,7 +815,7 @@ void BG_ParseConditionBits( char **text_pp, animStringItem_t *stringTable, int c
 	while ( !endFlag ) {
 
 		token = COM_ParseExt( text_pp, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			COM_RestoreParseSession( text_pp ); // go back to the previous token
 			endFlag = qtrue;    // done parsing indexes
 			if ( !strlen( currentString ) ) {
@@ -922,7 +922,7 @@ qboolean BG_ParseConditions( char **text_pp, animScriptItem_t *scriptItem ) {
 	while ( 1 ) {
 
 		token = COM_ParseExt( text_pp, qfalse );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			break;
 		}
 
@@ -940,7 +940,7 @@ qboolean BG_ParseConditions( char **text_pp, animScriptItem_t *scriptItem ) {
 		case ANIM_CONDTYPE_VALUE:
 			if ( animConditionsTable[conditionIndex].values ) {
 				token = COM_ParseExt( text_pp, qfalse );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_AnimParseAnimScript: expected condition value, found end of line" );  // RF modification
 					break;
 				}
@@ -986,7 +986,7 @@ void BG_ParseCommands( char **input, animScriptItem_t *scriptItem, animModelInfo
 
 		// parse the body part
 		token = COM_ParseExt( input, ( partIndex < 1 ) );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			break;
 		}
 		if ( !Q_stricmp( token, "}" ) ) {
@@ -1009,7 +1009,7 @@ void BG_ParseCommands( char **input, animScriptItem_t *scriptItem, animModelInfo
 		if ( command->bodyPart[partIndex] > 0 ) {
 			// parse the animation
 			token = COM_ParseExt( input, qfalse );
-			if ( !token || !token[0] ) {
+			if ( !token[0] ) {
 				BG_AnimParseError( "BG_ParseCommands: expected animation" );
 			}
 			command->animIndex[partIndex] = BG_AnimationIndexForString( token, parseClient );
@@ -1029,7 +1029,7 @@ void BG_ParseCommands( char **input, animScriptItem_t *scriptItem, animModelInfo
 				if ( !Q_stricmp( token, "duration" ) ) {
 					// read the duration
 					token = COM_ParseExt( input, qfalse );
-					if ( !token || !token[0] ) {
+					if ( !token[0] ) {
 						BG_AnimParseError( "BG_ParseCommands: expected duration value" );
 						break;
 					}
@@ -1052,14 +1052,14 @@ void BG_ParseCommands( char **input, animScriptItem_t *scriptItem, animModelInfo
 		// parse optional parameters (sounds, etc)
 		while ( 1 ) {
 			token = COM_ParseExt( input, qfalse );
-			if ( !token || !token[0] ) {
+			if ( !token[0] ) {
 				break;
 			}
 
 			if ( !Q_stricmp( token, "sound" ) ) {
 
 				token = COM_ParseExt( input, qfalse );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_ParseCommands: expected sound" );
 					break;
 				}
@@ -1072,7 +1072,7 @@ void BG_ParseCommands( char **input, animScriptItem_t *scriptItem, animModelInfo
 //----(SA)	added
 			} else if ( !Q_stricmp( token, "showpart" ) ) {    // show
 				token = COM_ParseExt( input, qfalse );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_ParseCommands: expected showpart number" );
 					break;
 				}
@@ -1083,7 +1083,7 @@ void BG_ParseCommands( char **input, animScriptItem_t *scriptItem, animModelInfo
 				command->accShowBits &= atoi( token );
 			} else if ( !Q_stricmp( token, "hidepart" ) ) {
 				token = COM_ParseExt( input, qfalse );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_ParseCommands: expected hidepart number" );
 					break;
 				}
@@ -1174,7 +1174,7 @@ void BG_AnimParseAnimScript( animModelInfo_t *modelInfo, animScriptData_t *scrip
 	while ( 1 ) {
 
 		token = COM_Parse( &text_p );
-		if ( !token || !token[0] ) {
+		if ( !token[0] ) {
 			if ( indentLevel ) {
 				BG_AnimParseError( "BG_AnimParseAnimScript: unexpected end of file: %s", token );
 			}
@@ -1202,14 +1202,14 @@ void BG_AnimParseAnimScript( animModelInfo_t *modelInfo, animScriptData_t *scrip
 
 				// read in the define type
 				token = COM_ParseExt( &text_p, qfalse );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_AnimParseAnimScript: expected condition type string" );   // RF mod
 				}
 				defineType = BG_IndexForString( token, animConditionsStr, qfalse );
 
 				// read in the define
 				token = COM_ParseExt( &text_p, qfalse );
-				if ( !token || !token[0] ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_AnimParseAnimScript: expected condition define string" ); // RF mod
 				}
 
@@ -1218,7 +1218,7 @@ void BG_AnimParseAnimScript( animModelInfo_t *modelInfo, animScriptData_t *scrip
 				defineStr[defineType][numDefines[defineType]].hash = BG_StringHashValue( defineStr[defineType][numDefines[defineType]].string );
 				// expecting an =
 				token = COM_ParseExt( &text_p, qfalse );
-				if ( !token ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_AnimParseAnimScript: expected '=', found end of line" );  // RF mod
 				}
 				if ( Q_stricmp( token, "=" ) ) {
@@ -1274,7 +1274,7 @@ void BG_AnimParseAnimScript( animModelInfo_t *modelInfo, animScriptData_t *scrip
 
 				// read in the state type
 				token = COM_ParseExt( &text_p, qfalse );
-				if ( !token ) {
+				if ( !token[0] ) {
 					BG_AnimParseError( "BG_AnimParseAnimScript: expected state type" );  // RF mod
 				}
 				indexes[indentLevel] = BG_IndexForString( token, animStateStr, qfalse );
@@ -1282,7 +1282,7 @@ void BG_AnimParseAnimScript( animModelInfo_t *modelInfo, animScriptData_t *scrip
 //----(SA) // RF mod
 				// check for the open bracket
 				token = COM_ParseExt( &text_p, qtrue );
-				if ( !token || Q_stricmp( token, "{" ) ) {
+				if ( !token[0] || Q_stricmp( token, "{" ) ) {
 					BG_AnimParseError( "BG_AnimParseAnimScript: expected '{'" );
 				}
 				indentLevel++;
@@ -1387,14 +1387,14 @@ void BG_AnimParseAnimScript( animModelInfo_t *modelInfo, animScriptData_t *scrip
 
 					// read in the old state type
 					token = COM_ParseExt( &text_p, qfalse );
-					if ( !token ) {
+					if ( !token[0] ) {
 						BG_AnimParseError( "BG_AnimParseAnimScript: expected <state type>" );    // RF mod
 					}
 					oldState = BG_IndexForString( token, animStateStr, qfalse );
 
 					// read in the new state type
 					token = COM_ParseExt( &text_p, qfalse );
-					if ( !token ) {
+					if ( !token[0] ) {
 						BG_AnimParseError( "BG_AnimParseAnimScript: expected <state type>" );    // RF mod
 					}
 					indexes[indentLevel] = BG_IndexForString( token, animStateStr, qfalse );
@@ -1404,7 +1404,7 @@ void BG_AnimParseAnimScript( animModelInfo_t *modelInfo, animScriptData_t *scrip
 //----(SA)		// RF mod
 					// check for the open bracket
 					token = COM_ParseExt( &text_p, qtrue );
-					if ( !token || Q_stricmp( token, "{" ) ) {
+					if ( !token[0] || Q_stricmp( token, "{" ) ) {
 						BG_AnimParseError( "BG_AnimParseAnimScript: expected '{'" );
 					}
 					indentLevel++;
