@@ -67,6 +67,7 @@ If you have questions concerning this license or the applicable additional terms
   #define HOMEPATH_NAME_WIN		"RTCW"
   #define STEAMPATH_NAME		"Return To Castle Wolfenstein"
   #define STEAMPATH_APPID		"9010"
+  #define GOGPATH_ID			"1441704976"
   #define HOMEPATH_NAME_MACOSX		HOMEPATH_NAME_WIN
   #define GAMENAME_FOR_MASTER		"wolfsp"
   #define CINEMATICS_LOGO		"gmlogo.RoQ"	// non-existent
@@ -84,7 +85,7 @@ If you have questions concerning this license or the applicable additional terms
 #define LEGACY_HEARTBEAT_FOR_MASTER	"Wolfenstein-1"
 
 #ifndef PRODUCT_VERSION
-  #define PRODUCT_VERSION "1.5a"
+  #define PRODUCT_VERSION "1.51b-SP"
 #endif
 
 #ifndef PRODUCT_DATE
@@ -994,8 +995,7 @@ SAVE
 	15 - (SA) moved time info above the main game reading
 	16 - (SA) added fog
 	17 - (SA) rats, changed fog.
-  18 - TTimo targetdeath fix
-	   show_bug.cgi?id=434
+	18 - TTimo targetdeath fix
 
 ==============================================================
 */
