@@ -516,11 +516,11 @@ static void RGBAtoNormal(const byte *in, byte *out, int width, int height, qbool
 
 					if (clampToEdge)
 					{
-						src_x = CLAMP(src_x, 0, height - 1);
+						src_x = CLAMP(src_x, 0, width - 1);
 					}
 					else
 					{
-						src_x = (src_x + height) % height;
+						src_x = (src_x + width) % width;
 					}
 
 					s[i++] = *(out + (src_y * width + src_x) * 4 + 3);
@@ -2844,7 +2844,7 @@ void R_CreateBuiltinImages( void ) {
 		height = glConfig.vidHeight;
 
 		hdrFormat = GL_RGBA8;
-		if (r_hdr->integer && glRefConfig.framebufferObject && glRefConfig.textureFloat)
+		if (r_hdr->integer && glRefConfig.textureFloat)
 			hdrFormat = GL_RGBA16F_ARB;
 
 		rgbFormat = GL_RGBA8;
