@@ -122,8 +122,6 @@ cvar_t  *r_ati_truform_pointmode;   // linear/cubic
 cvar_t  *r_ati_fsaa_samples;        //DAJ valids are 1, 2, 4
 //----(SA)	end
 
-cvar_t  *r_ext_draw_range_elements;
-cvar_t  *r_ext_multi_draw_arrays;
 cvar_t  *r_ext_framebuffer_object;
 cvar_t  *r_ext_texture_float;
 cvar_t  *r_ext_framebuffer_multisample;
@@ -131,9 +129,6 @@ cvar_t  *r_arb_seamless_cube_map;
 cvar_t  *r_arb_vertex_array_object;
 cvar_t  *r_ext_direct_state_access;
 
-cvar_t  *r_mergeMultidraws;
-cvar_t  *r_mergeLeafSurfaces;
-
 cvar_t  *r_cameraExposure;
 
 cvar_t  *r_externalGLSL;
@@ -346,7 +341,7 @@ static void InitOpenGL( void ) {
 	if ( glConfig.vidWidth == 0 ) {
 		GLint temp;
 
-		GLimp_Init();
+		GLimp_Init( qtrue );
 		GLimp_InitExtraExtensions();
 
 		strcpy( renderer_buffer, glConfig.renderer_string );
@@ -420,21 +415,39 @@ typedef struct vidmode_s
 	float pixelAspect;              // pixel width / height
 } vidmode_t;
 
+// Note: Also add these modes to ui/ui_shared.c  
 vidmode_t r_vidModes[] =
 {
-	{ "Mode  0: 320x240",        320,    240,    1 },
-	{ "Mode  1: 400x300",        400,    300,    1 },
-	{ "Mode  2: 512x384",        512,    384,    1 },
-	{ "Mode  3: 640x480",        640,    480,    1 },
-	{ "Mode  4: 800x600",        800,    600,    1 },
-	{ "Mode  5: 960x720",        960,    720,    1 },
-	{ "Mode  6: 1024x768",       1024,   768,    1 },
-	{ "Mode  7: 1152x864",       1152,   864,    1 },
-	{ "Mode  8: 1280x1024",      1280,   1024,   1 },
-	{ "Mode  9: 1600x1200",      1600,   1200,   1 },
-	{ "Mode 10: 2048x1536",      2048,   1536,   1 },
-	{ "Mode 11: 856x480 (wide)",856, 480,    1 },
-	{ "Mode 12: 1920x1200 (wide)",1920,  1200,   1 }     //----(SA)	added
+	{ "Mode  0:   320x240   (4:3)",     320,     240,    1 },
+	{ "Mode  1:   400x300   (4:3)",     400,     300,    1 },
+	{ "Mode  2:   512x384   (4:3)",     512,     384,    1 },
+	{ "Mode  3:   640x480   (4:3)",     640,     480,    1 },
+	{ "Mode  4:   800x600   (4:3)",     800,     600,    1 },
+	{ "Mode  5:   960x720   (4:3)",     960,     720,    1 },
+	{ "Mode  6:  1024x768   (4:3)",    1024,     768,    1 },
+	{ "Mode  7:  1152x864   (4:3)",    1152,     864,    1 },
+	{ "Mode  8: 1280x1024   (5:4)",    1280,    1024,    1 },
+	{ "Mode  9: 1600x1200   (4:3)",    1600,    1200,    1 },
+	{ "Mode 10: 2048x1536   (4:3)",    2048,    1536,    1 },
+	{ "Mode 11:   856x480  (16:9)",     856,     480,    1 },
+	{ "Mode 12:   640x360  (16:9)",     640,     360,    1 },
+	{ "Mode 13:   640x400 (16:10)",     640,     400,    1 },
+	{ "Mode 14:   800x450  (16:9)",     800,     450,    1 },
+	{ "Mode 15:   800x500 (16:10)",     800,     500,    1 },
+	{ "Mode 16:  1024x640 (16:10)",    1024,     640,    1 },
+	{ "Mode 17:  1024x576  (16:9)",    1024,     576,    1 },
+	{ "Mode 18:  1280x720  (16:9)",    1280,     720,    1 },
+	{ "Mode 19:  1280x768 (16:10)",    1280,     768,    1 },
+	{ "Mode 20:  1280x800 (16:10)",    1280,     800,    1 },
+	{ "Mode 21:  1280x960   (4:3)",    1280,     960,    1 },
+	{ "Mode 22:  1440x900 (16:10)",    1440,     900,    1 },
+	{ "Mode 23:  1600x900  (16:9)",    1600,     900,    1 },
+	{ "Mode 24: 1600x1000 (16:10)",    1600,    1000,    1 },
+	{ "Mode 25: 1680x1050 (16:10)",    1680,    1050,    1 },
+	{ "Mode 26: 1920x1080  (16:9)",    1920,    1080,    1 },
+	{ "Mode 27: 1920x1200 (16:10)",    1920,    1200,    1 },
+	{ "Mode 28: 1920x1440   (4:3)",    1920,    1440,    1 },
+	{ "Mode 29: 2560x1600 (16:10)",    2560,    1600,    1 }
 };
 static int	s_numVidModes = ARRAY_LEN( r_vidModes );
 
@@ -1022,12 +1035,11 @@ void GL_SetDefaultState( void ) {
 
 	qglCullFace( GL_FRONT );
 
-	qglColor4f( 1,1,1,1 );
-
 	GL_BindNullTextures();
-	GL_BindNullFramebuffers();
 
-	qglEnable( GL_TEXTURE_2D );
+	if (glRefConfig.framebufferObject)
+		GL_BindNullFramebuffers();
+
 	GL_TextureMode( r_textureMode->string );
 
 	//qglShadeModel( GL_SMOOTH );
@@ -1071,9 +1083,11 @@ void GL_SetDefaultState( void ) {
 	// ATI pn_triangles
 	if ( qglPNTrianglesiATI ) {
 		int maxtess;
+
 		// get max supported tesselation
 		qglGetIntegerv( GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI, (GLint*)&maxtess );
 		glConfig.ATIMaxTruformTess = maxtess;
+
 		// cap if necessary
 		if ( r_ati_truform_tess->value > maxtess ) {
 			ri.Cvar_Set( "r_ati_truform_tess", va( "%d", maxtess ) );
@@ -1083,6 +1097,7 @@ void GL_SetDefaultState( void ) {
 		qglPNTrianglesiATI( GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI, r_ati_truform_tess->value );
 	}
 
+#if 0
 	if ( glConfig.anisotropicAvailable ) {
 		float maxAnisotropy;
 
@@ -1090,8 +1105,9 @@ void GL_SetDefaultState( void ) {
 		glConfig.maxAnisotropy = maxAnisotropy;
 
 		// set when rendering
-//	   qglTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, glConfig.maxAnisotropy);
+		//qglTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, glConfig.maxAnisotropy);
 	}
+#endif
 //----(SA)	end
 }
 
@@ -1153,7 +1169,21 @@ void GfxInfo_f( void ) {
 	ri.Printf( PRINT_ALL, "GL_RENDERER: %s\n", glConfig.renderer_string );
 	ri.Printf( PRINT_ALL, "GL_VERSION: %s\n", glConfig.version_string );
 	ri.Printf( PRINT_ALL, "GL_EXTENSIONS: " );
-	R_PrintLongString( glConfig.extensions_string );
+	if (glRefConfig.openglMajorVersion >= 3)
+	{
+		GLint numExtensions;
+		int i;
+
+		glGetIntegerv(GL_NUM_EXTENSIONS, &numExtensions);
+		for (i = 0; i < numExtensions; i++)
+		{
+			ri.Printf(PRINT_ALL, "%s ", qglGetStringi(GL_EXTENSIONS, i));
+		}
+	}
+	else
+	{
+		R_PrintLongString( glConfig.extensions_string );
+	}
 	ri.Printf( PRINT_ALL, "\n" );
 	ri.Printf( PRINT_ALL, "GL_MAX_TEXTURE_SIZE: %d\n", glConfig.maxTextureSize );
 	ri.Printf( PRINT_ALL, "GL_MAX_TEXTURE_UNITS_ARB: %d\n", glConfig.numTextureUnits );
@@ -1176,7 +1206,6 @@ void GfxInfo_f( void ) {
 	ri.Printf( PRINT_ALL, "picmip: %d\n", r_picmip->integer );
 	ri.Printf( PRINT_ALL, "picmip2: %d\n", r_picmip2->integer );
 	ri.Printf( PRINT_ALL, "texture bits: %d\n", r_texturebits->integer );
-	ri.Printf( PRINT_ALL, "multitexture: %s\n", enablestrings[qglActiveTextureARB != 0] );
 	ri.Printf( PRINT_ALL, "compiled vertex arrays: %s\n", enablestrings[qglLockArraysEXT != 0 ] );
 	ri.Printf( PRINT_ALL, "texenv add: %s\n", enablestrings[glConfig.textureEnvAddAvailable != 0] );
 	ri.Printf( PRINT_ALL, "compressed textures: %s\n", enablestrings[glConfig.textureCompression != TC_NONE] );
@@ -1277,7 +1306,7 @@ void R_Register( void ) {
 	// latched and archived variables
 	//
 	r_allowExtensions = ri.Cvar_Get( "r_allowExtensions", "1", CVAR_ARCHIVE | CVAR_LATCH );
-	r_ext_compressed_textures = ri.Cvar_Get( "r_ext_compressed_textures", "1", CVAR_ARCHIVE | CVAR_LATCH );   // (SA) ew, a spelling change I missed from the missionpack
+	r_ext_compressed_textures = ri.Cvar_Get( "r_ext_compressed_textures", "0", CVAR_ARCHIVE | CVAR_LATCH );   // (SA) ew, a spelling change I missed from the missionpack
 	r_ext_multitexture = ri.Cvar_Get( "r_ext_multitexture", "1", CVAR_ARCHIVE | CVAR_LATCH );
 	r_ext_compiled_vertex_array = ri.Cvar_Get( "r_ext_compiled_vertex_array", "1", CVAR_ARCHIVE | CVAR_LATCH );
 	r_glIgnoreWicked3D = ri.Cvar_Get( "r_glIgnoreWicked3D", "0", CVAR_ARCHIVE | CVAR_LATCH );
@@ -1297,8 +1326,6 @@ void R_Register( void ) {
 
 	r_ext_texture_env_add = ri.Cvar_Get( "r_ext_texture_env_add", "1", CVAR_ARCHIVE | CVAR_LATCH );
 
-	r_ext_draw_range_elements = ri.Cvar_Get( "r_ext_draw_range_elements", "1", CVAR_ARCHIVE | CVAR_LATCH);
-	r_ext_multi_draw_arrays = ri.Cvar_Get( "r_ext_multi_draw_arrays", "1", CVAR_ARCHIVE | CVAR_LATCH);
 	r_ext_framebuffer_object = ri.Cvar_Get( "r_ext_framebuffer_object", "1", CVAR_ARCHIVE | CVAR_LATCH);
 	r_ext_texture_float = ri.Cvar_Get( "r_ext_texture_float", "1", CVAR_ARCHIVE | CVAR_LATCH);
 	r_ext_framebuffer_multisample = ri.Cvar_Get( "r_ext_framebuffer_multisample", "0", CVAR_ARCHIVE | CVAR_LATCH);
@@ -1453,8 +1480,6 @@ void R_Register( void ) {
 	r_directedScale = ri.Cvar_Get( "r_directedScale", "1", CVAR_CHEAT );
 
 	r_anaglyphMode = ri.Cvar_Get("r_anaglyphMode", "0", CVAR_ARCHIVE);
-	r_mergeMultidraws = ri.Cvar_Get("r_mergeMultidraws", "1", CVAR_ARCHIVE);
-	r_mergeLeafSurfaces = ri.Cvar_Get("r_mergeLeafSurfaces", "1", CVAR_ARCHIVE);
 
 	//
 	// temporary variables that can change at any time
@@ -1674,16 +1699,15 @@ void RE_Shutdown( qboolean destroyWindow ) {
 
 	ri.Printf( PRINT_ALL, "RE_Shutdown( %i )\n", destroyWindow );
 
-	ri.Cmd_RemoveCommand( "modellist" );
-	ri.Cmd_RemoveCommand( "screenshotJPEG" );
-	ri.Cmd_RemoveCommand( "screenshot" );
 	ri.Cmd_RemoveCommand( "imagelist" );
 	ri.Cmd_RemoveCommand( "shaderlist" );
 	ri.Cmd_RemoveCommand( "skinlist" );
-	ri.Cmd_RemoveCommand( "gfxinfo" );
-	ri.Cmd_RemoveCommand("minimize");
+	ri.Cmd_RemoveCommand( "modellist" );
 	ri.Cmd_RemoveCommand( "modelist" );
-	ri.Cmd_RemoveCommand( "shaderstate" );
+	ri.Cmd_RemoveCommand( "screenshot" );
+	ri.Cmd_RemoveCommand( "screenshotJPEG" );
+	ri.Cmd_RemoveCommand( "gfxinfo" );
+	ri.Cmd_RemoveCommand( "minimize" );
 	ri.Cmd_RemoveCommand( "gfxmeminfo" );
 	ri.Cmd_RemoveCommand( "exportCubemaps" );
 	ri.Cmd_RemoveCommand( "taginfo" );
@@ -1801,10 +1825,6 @@ refexport_t *GetRefAPI( int apiVersion, refimport_t *rimp ) {
 	re.GetEntityToken   = R_GetEntityToken;
 	re.TakeVideoFrame = RE_TakeVideoFrame;
 
-#ifdef BLAH // MrE __USEA3D
-	re.A3D_RenderGeometry = RE_A3D_RenderGeometry;
-#endif
-
 	// RF
 	re.ZombieFXAddNewHit = RB_ZombieFXAddNewHit;
 
