@@ -746,7 +746,7 @@ static void SV_Ban_f( void ) {
 	}
 
 	if ( cl->netchan.remoteAddress.type == NA_LOOPBACK ) {
-		Com_Printf("Cannot kick host player\n");
+		Com_Printf("Cannot ban host player\n");
 		return;
 	}
 
@@ -1464,6 +1464,7 @@ static void SV_ConSay_f( void ) {
 
 	strcat( text, p );
 
+	Com_Printf("%s\n", text);
 	SV_SendServerCommand( NULL, "chat \"%s\"", text );
 }
 
@@ -1503,6 +1504,7 @@ static void SV_ConTell_f(void) {
 
 	strcat(text, p);
 
+	Com_Printf("%s\n", text);
 	SV_SendServerCommand(cl, "chat \"%s\"", text);
 }
 
